
# PyAMS
PyAMS: Python for Analog and Mixed Signals

<h1 align="center">
    <a href="https://pyams.sourceforge.io/"><img src="https://pyams.sourceforge.io/logo.png" width="175px" alt="PyAMS"></a>
</h1>

---

<p align="center">
 
 <a href="#News">
    <img src="https://img.shields.io/badge/Version-0.1.3-blue" alt="V 0.1.3">
 </a>
  <a href="#Installation">
      <img src="https://img.shields.io/badge/Python->=3-blue" alt="Python 3+">
  </a>
    
  <a href="https://github.com/d-fathi/PyAMS/blob/main/LICENSE">
      <img src="https://img.shields.io/badge/GPLv3-blue" alt="GPLv3">
  </a>
</p>


**************
What is PyAMS?
**************

PyAMS is a software used to simplify simulate electronic circuit and  modeling analog elements  using pyams_lib
The objectives of PyAMS is:

*	Drawing circuit by schematic;
*	Creating new symbols for models;
*	Creating new PyAMS models of electrical elements by using pyams_lib;
*	Simulating the circuit in the selected mode of operation;
*	Presenting simulation results in a dedicated waveform editor or probe;
*   PyAMS used Python3+ or PyPy and works on  Windows , Linux (future), and OSX(future).
*   **Licensed under:** PyAMS is free to use. GPLv3.


## Web Site of Software

* **Hom page** <a href="https://pyams.sf.net">https://pyams.sf.net</a>.
* **PyAMS’s documentation**  <a href="https://pyams.sf.net/doc">https://pyams.sf.net/doc</a>.

## Installation of Software

* **Download:** <a href="https://sourceforge.net/projects/pyams/">https://sourceforge.net/projects/pyams/</a>.

## Screenshots of schematic and data display areas

<h1 align="center">
    <img src="https://pyams.sourceforge.io/images/C.png" width="900px" alt="PyAMS">
</h1>


## Installation by pip

To install `pyams_cad`, use the following command:

```sh
pip install pyams_cad
```

To upgrade to the latest version:

```sh
pip install --upgrade pyams_cad
```

### Code:

```python

from pyams import win
win()

````






